# Changelog

The first official release of pelican-mboxreader was actually 0.1.1; version 0.1.0 was
a testing version that, while deployed, was never officially uploaded anywhere. Thus
the first version that actually has a changelog is 0.1.2.

## Version 0.1.4 - 06/05/20

* Use sub-logger instead of the root logger (#7).

## Version 0.1.3 - 12/29/16

* Fixes to the Python 3 support.
* Make pypandoc an optional dependency.

## Version 0.1.2 - 3/5/16

* Use pypandoc to convert README.md into rST when uploading to PyPI.

## Version 0.1.1 - 3/5/16

* First official/public release.
